@@ -11,8 +11,10 @@ pub const HISTORY_PAGE_SIZE: i64 = 100;
 pub struct Settings {
     pub host: String,
     pub port: u16,
+    pub path: String,
     pub db_uri: String,
     pub open_registration: bool,
+    pub max_history_length: usize,
 }
 
 impl Settings {
@@ -33,6 +35,8 @@ impl Settings {
             .set_default("host", "127.0.0.1")?
             .set_default("port", 8888)?
             .set_default("open_registration", false)?
+            .set_default("max_history_length", 8192)?
+            .set_default("path", "")?
             .add_source(
                 Environment::with_prefix("atuin")
                     .prefix_separator("_")
